@@ -13,8 +13,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 
 namespace crl {
 
-queue::queue() : _list(&_sentinel_semaphore) {
-}
+queue::queue() = default;
 
 queue::queue(queue_processor processor) : _main_processor(processor) {
 }
@@ -39,12 +38,6 @@ void queue::process() {
 	}
 }
 
-queue::~queue() {
-	if (!_main_processor && _list.push_sentinel()) {
-		wake_async();
-	}
-}
-
 void queue::ProcessCallback(void *that) {
 	static_cast<queue*>(that)->process();
 }
